@@ -26,13 +26,13 @@ using namespace KScreen;
 
 Q_LOGGING_CATEGORY(KSCREEN_QSCREEN, "kscreen.qscreen")
 
-QScreenConfig *QScreenBackend::s_internalConfig = 0;
+QScreenConfig *QScreenBackend::s_internalConfig = nullptr;
 
 QScreenBackend::QScreenBackend()
     : KScreen::AbstractBackend()
     , m_isValid(true)
 {
-    if (s_internalConfig == 0) {
+    if (s_internalConfig == nullptr) {
         s_internalConfig = new QScreenConfig();
         connect(s_internalConfig, &QScreenConfig::configChanged,
                 this, &QScreenBackend::configChanged);
@@ -45,12 +45,12 @@ QScreenBackend::~QScreenBackend()
 
 QString QScreenBackend::name() const
 {
-    return QString("QScreen");
+    return QStringLiteral("QScreen");
 }
 
 QString QScreenBackend::serviceName() const
 {
-    return QLatin1Literal("org.kde.KScreen.Backend.QScreen");
+    return QStringLiteral("org.kde.KScreen.Backend.QScreen");
 }
 
 
