@@ -36,8 +36,8 @@ class QScreenOutput : public QObject
     Q_OBJECT
 
 public:
-    explicit QScreenOutput(const QScreen *qscreen, QObject *parent = 0);
-    virtual ~QScreenOutput();
+    explicit QScreenOutput(const QScreen *qscreen, QObject *parent = nullptr);
+    ~QScreenOutput() override;
 
     KScreen::OutputPtr toKScreenOutput() const;
     void updateKScreenOutput(KScreen::OutputPtr &output) const;
