@@ -38,7 +38,7 @@ class KSCREEN_EXPORT AbstractBackend : public QObject
     Q_OBJECT
 
 public:
-    virtual ~AbstractBackend() {}
+    ~AbstractBackend() override {}
 
     /**
      * This is where the backend should perform all initialization. This method
@@ -51,21 +51,21 @@ public:
     virtual void init(const QVariantMap &arguments);
 
     /**
-     * Returns user-friendly name of the backend
+     * Returns a user-friendly name of the backend.
      */
     virtual QString name() const = 0;
 
     /**
-     * Returns name of DBus service that should be used for this backend
+     * Returns the name of the DBus service that should be used for this backend.
      *
-     * Each backend must have unique service name (usually something like
-     * org.kde.KScreen.Backend.%backendName% to allow multiple different backends
+     * Each backend must have an unique service name (usually something like
+     * org.kde.KScreen.Backend.%backendName%) to allow multiple different backends
      * running concurrently.
      */
     virtual QString serviceName() const = 0;
 
     /**
-     * Returns a new Config object, holding Screen, Output objects, etc
+     * Returns a new Config object, holding Screen, Output objects, etc.
      *
      * @return Config object for the system.
      */
@@ -82,7 +82,7 @@ public:
      * Returns whether the backend is in valid state.
      *
      * Backends should use this to tell BackendLauncher whether they are capable
-     * of operating on current platform
+     * of operating on the current platform.
      */
     virtual bool isValid() const = 0;
 
@@ -100,9 +100,9 @@ Q_SIGNALS:
     /**
      * Emitted when backend detects a change in configuration
      *
-     * It's OK to emit signal for every single change. The emissions are aggregated
-     * in backend launcher, so that the backend does not spam DBus and client
-     * applications
+     * It's OK to emit this signal for every single change. The emissions are aggregated
+     * in the backend launcher, so that the backend does not spam DBus and client
+     * applications.
      *
      * @param config New configuration
      */
